This crate provides low-level FFI bindings for EOSIO smart contract
development. Bindings are automatically generated with bindgen
from header files in the EOSIO/eosio.cdt repository.
For more idiomatic Rust wrappers please see the eosio and
eosio_cdt crates.
Structs
- capi_
checksum160 - 160-bit hash
- capi_
checksum256 - 256-bit hash
- capi_
checksum512 - 512-bit hash
- capi_
public_ key - EOSIO Public Key. K1 and R1 keys are 34 bytes. Newer keys can be variable-sized
- capi_
signature - EOSIO Signature. K1 and R1 signatures are 66 bytes. Newer signatures can be variable-sized
Enums
Functions
- action_
data_ ⚠size - Get the length of the current action’s data field. This method is useful for dynamically sized actions
- assert_
recover_ ⚠key - Tests a given public key with the generated key from digest and the signature.
- assert_
ripemd160 ⚠ - Tests if the ripemod160 hash generated from data matches the provided checksum.
- assert_
sha1 ⚠ - Tests if the sha1 hash generated from data matches the provided checksum.
- assert_
sha256 ⚠ - Tests if the sha256 hash generated from data matches the provided checksum.
- assert_
sha512 ⚠ - Tests if the sha512 hash generated from data matches the provided checksum.
- cancel_
deferred ⚠ - Cancels a deferred transaction.
- check_
permission_ ⚠authorization - Checks if a permission is authorized by a provided delay and a provided set of keys and permissions
- check_
transaction_ ⚠authorization - Checks if a transaction is authorized by a provided set of keys and permissions
- current_
receiver ⚠ - Get the current receiver of the action @brief Get the current receiver of the action @return the account which specifies the current receiver of the action
- current_
time ⚠ - Returns the time in microseconds from 1970 of the current block
- db_
end_ ⚠i64 - Get an iterator representing just-past-the-end of the last table row of a primary 64-bit integer index table
- db_
find_ ⚠i64 - Find a table row in a primary 64-bit integer index table by primary key
- db_
get_ ⚠i64 - Get a record in a primary 64-bit integer index table
- db_
idx64_ ⚠end - Get an end iterator representing just-past-the-end of the last table row of a secondary 64-bit integer index table
- db_
idx64_ ⚠find_ primary - Find a table row in a secondary 64-bit integer index table by primary key
- db_
idx64_ ⚠find_ secondary - Find a table row in a secondary 64-bit integer index table by secondary key
- db_
idx64_ ⚠lowerbound - Find the table row in a secondary 64-bit integer index table that matches the lowerbound condition for a given secondary key The table row that matches the lowerbound condition is the first table row in the table with the lowest secondary key that is >= the given key
- db_
idx64_ ⚠next - Find the table row following the referenced table row in a secondary 64-bit integer index table
- db_
idx64_ ⚠previous - Find the table row preceding the referenced table row in a secondary 64-bit integer index table
- db_
idx64_ ⚠remove - Remove a table row from a secondary 64-bit integer index table
- db_
idx64_ ⚠store - Store an association of a 64-bit integer secondary key to a primary key in a secondary 64-bit integer index table
- db_
idx64_ ⚠update - Update an association for a 64-bit integer secondary key to a primary key in a secondary 64-bit integer index table
- db_
idx64_ ⚠upperbound - Find the table row in a secondary 64-bit integer index table that matches the upperbound condition for a given secondary key The table row that matches the upperbound condition is the first table row in the table with the lowest secondary key that is > the given key
- db_
idx128_ ⚠end - Get an end iterator representing just-past-the-end of the last table row of a secondary 128-bit integer index table
- db_
idx128_ ⚠find_ primary - Find a table row in a secondary 128-bit integer index table by primary key
- db_
idx128_ ⚠find_ secondary - Find a table row in a secondary 128-bit integer index table by secondary key
- db_
idx128_ ⚠lowerbound - Find the table row in a secondary 128-bit integer index table that matches the lowerbound condition for a given secondary key The table row that matches the lowerbound condition is the first table row in the table with the lowest secondary key that is >= the given key
- db_
idx128_ ⚠next - Find the table row following the referenced table row in a secondary 128-bit integer index table
- db_
idx128_ ⚠previous - Find the table row preceding the referenced table row in a secondary 128-bit integer index table
- db_
idx128_ ⚠remove - Remove a table row from a secondary 128-bit integer index table
- db_
idx128_ ⚠store - Store an association of a 128-bit integer secondary key to a primary key in a secondary 128-bit integer index table
- db_
idx128_ ⚠update - Update an association for a 128-bit integer secondary key to a primary key in a secondary 128-bit integer index table
- db_
idx128_ ⚠upperbound - Find the table row in a secondary 128-bit integer index table that matches the upperbound condition for a given secondary key The table row that matches the upperbound condition is the first table row in the table with the lowest secondary key that is > the given key
- db_
idx256_ ⚠end - Get an end iterator representing just-past-the-end of the last table row of a secondary 256-bit index table
- db_
idx256_ ⚠find_ primary - Find a table row in a secondary 256-bit index table by primary key
- db_
idx256_ ⚠find_ secondary - Find a table row in a secondary 256-bit index table by secondary key
- db_
idx256_ ⚠lowerbound - Find the table row in a secondary 256-bit index table that matches the lowerbound condition for a given secondary key The table row that matches the lowerbound condition is the first table row in the table with the lowest secondary key that is >= the given key (uses lexicographical ordering on the 256-bit keys)
- db_
idx256_ ⚠next - Find the table row following the referenced table row in a secondary 256-bit index table
- db_
idx256_ ⚠previous - Find the table row preceding the referenced table row in a secondary 256-bit index table
- db_
idx256_ ⚠remove - Remove a table row from a secondary 256-bit index table
- db_
idx256_ ⚠store - Store an association of a 256-bit secondary key to a primary key in a secondary 256-bit index table
- db_
idx256_ ⚠update - Update an association for a 256-bit secondary key to a primary key in a secondary 256-bit index table
- db_
idx256_ ⚠upperbound - Find the table row in a secondary 256-bit index table that matches the upperbound condition for a given secondary key The table row that matches the upperbound condition is the first table row in the table with the lowest secondary key that is > the given key (uses lexicographical ordering on the 256-bit keys)
- db_
idx_ ⚠double_ end - Get an end iterator representing just-past-the-end of the last table row of a secondary double-precision floating-point index table
- db_
idx_ ⚠double_ find_ primary - Find a table row in a secondary double-precision floating-point index table by primary key
- db_
idx_ ⚠double_ find_ secondary - Find a table row in a secondary double-precision floating-point index table by secondary key
- db_
idx_ ⚠double_ lowerbound - Find the table row in a secondary double-precision floating-point index table that matches the lowerbound condition for a given secondary key The table row that matches the lowerbound condition is the first table row in the table with the lowest secondary key that is >= the given key
- db_
idx_ ⚠double_ next - Find the table row following the referenced table row in a secondary double-precision floating-point index table
- db_
idx_ ⚠double_ previous - Find the table row preceding the referenced table row in a secondary double-precision floating-point index table
- db_
idx_ ⚠double_ remove - Remove a table row from a secondary double-precision floating-point index table
- db_
idx_ ⚠double_ store - Store an association of a double-precision floating-point secondary key to a primary key in a secondary double-precision floating-point index table
- db_
idx_ ⚠double_ update - Update an association for a double-precision floating-point secondary key to a primary key in a secondary double-precision floating-point index table
- db_
idx_ ⚠double_ upperbound - Find the table row in a secondary double-precision floating-point index table that matches the upperbound condition for a given secondary key The table row that matches the upperbound condition is the first table row in the table with the lowest secondary key that is > the given key
- db_
idx_ ⚠long_ double_ end - Get an end iterator representing just-past-the-end of the last table row of a secondary quadruple-precision floating-point index table
- db_
idx_ ⚠long_ double_ find_ primary - Find a table row in a secondary quadruple-precision floating-point index table by primary key
- db_
idx_ ⚠long_ double_ find_ secondary - Find a table row in a secondary quadruple-precision floating-point index table by secondary key
- db_
idx_ ⚠long_ double_ lowerbound - Find the table row in a secondary quadruple-precision floating-point index table that matches the lowerbound condition for a given secondary key The table row that matches the lowerbound condition is the first table row in the table with the lowest secondary key that is >= the given key
- db_
idx_ ⚠long_ double_ next - Find the table row following the referenced table row in a secondary quadruple-precision floating-point index table
- db_
idx_ ⚠long_ double_ previous - Find the table row preceding the referenced table row in a secondary quadruple-precision floating-point index table
- db_
idx_ ⚠long_ double_ remove - Remove a table row from a secondary quadruple-precision floating-point index table
- db_
idx_ ⚠long_ double_ store - Store an association of a quadruple-precision floating-point secondary key to a primary key in a secondary quadruple-precision floating-point index table
- db_
idx_ ⚠long_ double_ update - Update an association for a quadruple-precision floating-point secondary key to a primary key in a secondary quadruple-precision floating-point index table
- db_
idx_ ⚠long_ double_ upperbound - Find the table row in a secondary quadruple-precision floating-point index table that matches the upperbound condition for a given secondary key The table row that matches the upperbound condition is the first table row in the table with the lowest secondary key that is > the given key
- db_
lowerbound_ ⚠i64 - Find the table row in a primary 64-bit integer index table that matches the lowerbound condition for a given primary key The table row that matches the lowerbound condition is the first table row in the table with the lowest primary key that is >= the given key
- db_
next_ ⚠i64 - Find the table row following the referenced table row in a primary 64-bit integer index table
- db_
previous_ ⚠i64 - Find the table row preceding the referenced table row in a primary 64-bit integer index table
- db_
remove_ ⚠i64 - Remove a record from a primary 64-bit integer index table
- db_
store_ ⚠i64 - Store a record in a primary 64-bit integer index table
- db_
update_ ⚠i64 - Update a record in a primary 64-bit integer index table
- db_
upperbound_ ⚠i64 - Find the table row in a primary 64-bit integer index table that matches the upperbound condition for a given primary key The table row that matches the upperbound condition is the first table row in the table with the lowest primary key that is > the given key
- eosio_
assert ⚠ - Aborts processing of this action and unwinds all pending changes if the test condition is true
- eosio_
assert_ ⚠code - Aborts processing of this action and unwinds all pending changes if the test condition is true
- eosio_
assert_ ⚠message - Aborts processing of this action and unwinds all pending changes if the test condition is true
- eosio_
exit ⚠ - This method will abort execution of wasm without failing the contract. This is used to bypass all cleanup / destructors that would normally be called.
- expiration⚠
- Gets the expiration of the currently executing transaction.
- get_
account_ ⚠creation_ time - Returns the creation time of an account
- get_
action ⚠ - Retrieves the indicated action from the active transaction.
- get_
active_ ⚠producers - Gets the set of active producers.
- get_
blockchain_ ⚠parameters_ packed - Retrieve the blolckchain parameters
- get_
context_ ⚠free_ data - Retrieve the signed_transaction.context_free_data[index].
- get_
permission_ ⚠last_ used - Returns the last used time of a permission
- get_
resource_ ⚠limits - Get the resource limits of an account
- get_
sender ⚠ - Return name of account that sent current inline action
- has_
auth ⚠ - Verifies that name has auth.
- is_
account ⚠ - Verifies that @ref name is an existing account.
- is_
feature_ ⚠activated - Check if specified protocol feature has been activated
- is_
privileged ⚠ - Check if an account is privileged
- preactivate_
feature ⚠ - Pre-activate protocol feature
- printdf⚠
- Prints value as double-precision floating point number
- printhex⚠
- Prints hexidecimal data of length datalen
- printi⚠
- Prints value as a 64 bit signed integer
- printi128⚠
- Prints value as a 128 bit signed integer
- printn⚠
- Prints a 64 bit names as base32 encoded string
- printqf⚠
- Prints value as quadruple-precision floating point number
- prints⚠
- Prints string
- prints_
l ⚠ - Prints string up to given length
- printsf⚠
- Prints value as single-precision floating point number
- printui⚠
- Prints value as a 64 bit unsigned integer
- printui128⚠
- Prints value as a 128 bit unsigned integer
- publication_
time ⚠ - Returns the time in microseconds from 1970 of the publication_time @brief Get the publication time @return the time in microseconds from 1970 of the publication_time
- read_
action_ ⚠data - Copy up to length bytes of current action data to the specified location
- read_
transaction ⚠ - Access a copy of the currently executing transaction.
- recover_
key ⚠ - Calculates the public key used for a given signature and hash used to create a message.
- require_
auth ⚠ - Verifies that name exists in the set of provided auths on a action. Throws if not found.
- require_
auth2 ⚠ - Verifies that name exists in the set of provided auths on a action. Throws if not found.
- require_
recipient ⚠ - Add the specified account to set of accounts to be notified
- ripemd160⚠
- Hashes
datausingripemod160and stores result in memory pointed to by hash. - send_
context_ ⚠free_ inline - /function Send an inline context free action in the context of this action’s parent transaction
- send_
deferred ⚠ - Sends a deferred transaction.
- send_
inline ⚠ - Send an inline action in the context of this action’s parent transaction
- set_
blockchain_ ⚠parameters_ packed - Set the blockchain parameters
- set_
privileged ⚠ - Set the privileged status of an account
- set_
proposed_ ⚠producers - Proposes a schedule change
- set_
resource_ ⚠limits - Set the resource limits of an account
- sha1⚠
- Hashes
datausingsha1and stores result in memory pointed to by hash. - sha256⚠
- Hashes
datausingsha256and stores result in memory pointed to by hash. - sha512⚠
- Hashes
datausingsha512and stores result in memory pointed to by hash. - tapos_
block_ ⚠num - Gets the block number used for TAPOS on the currently executing transaction.
- tapos_
block_ ⚠prefix - Gets the block prefix used for TAPOS on the currently executing transaction.
- transaction_
size ⚠ - Gets the size of the currently executing transaction.